# WWTP Python API


## Description
This repository contains the subs and annotations that can be used to add custom processes to WWTP.

## Requirements

Python 3.10 or higher.

## Installation

Install using pip: `pip install wwtp-api-rhdhv`.